@@ -2,5 +2,5 @@ import PageEditor from './helpers/PageEditor';
 
 
 (function initCMS() {
-  PageEditor.initAll();
+ /* PageEditor.initAll();*/
 }());
